@@ -1,5 +1,6 @@
 /*
  * JFBTERM -
+ * Copyright (c) 2003 Fumitoshi UKAI <ukai@debian.or.jp>
  * Copyright (C) 1999  Noritoshi MASUICHI (nmasu@ma3.justnet.ne.jp)
  *
  * Redistribution and use in source and binary forms, with or without
@@ -194,7 +195,6 @@ void tapp_change_to_new_console(TApplication* p)
         int vfd;
         int vtNum;
         int child;
-        int parent;
         char vtty[128];
         int mode;
 
@@ -217,7 +217,8 @@ void tapp_change_to_new_console(TApplication* p)
         if (vtNum < 0) {
                 die("can't get free VC");
         }
-        parent = getpid();
+	fflush(stdout);
+	fflush(stderr);
         if ((child = fork()) == -1) {
                 print_strerror_and_exit("fork");
         }
@@ -331,17 +332,17 @@ char *
 tapp_setup_encoding(char *en)
 {
 	/* if quoted, remove it */
-	if ((en[0] == '"' && en[strlen(en)-1] == '"') 
-	    || (en[0] == '\'' && en[strlen(en)-1] == '\'')) {
+	if (en && ((en[0] == '"' && en[strlen(en)-1] == '"') 
+		   || (en[0] == '\'' && en[strlen(en)-1] == '\''))) {
 		en = en + 1;
 		en[strlen(en)-1] = '\0';
 	}
-	if (strcmp(en, "locale") == 0) {
+	if (en == NULL || strcmp(en, "locale") == 0) {
 		setlocale(LC_ALL, "");
 		en = nl_langinfo(CODESET);
 		print_message("ENCODING: locale = %s\n", en);
 	}
-	if (strchr(en, ',') == NULL) {
+	if (en && (strchr(en, ',') == NULL)) {
 		char *encname = en;
 		en = tcaps_find_entry(&(gApp.gCaps), "encoding.", encname);
 		if (!en) {
@@ -416,6 +417,7 @@ int main(int argc, char *argv[])
 	if ((cp = tcaps_find_first(&(gApp.gCaps), "color.gamma")) != NULL) {
 		fbgamma = (float)atof(cp);
 	}
+	tfont_setup_fontlist(fcap->values);
 	print_message("encoding : %s\n", en);
 	print_message("exec : %s ", gApp.gExecShell);
 	{
@@ -426,7 +428,6 @@ int main(int argc, char *argv[])
 
 	tapp_change_to_new_console(&gApp);
 	tfbm_init(&gFramebuffer);
-	tfont_setup_fontlist(fcap->values);
 	tfbm_open(&gFramebuffer);
 
 	util_privilege_drop();
