@@ -1125,7 +1125,7 @@ static void tvterm_esc_report(TVterm* p, u_char mode, u_short arg)
 		}
 		break;
 	}
-	write(p->term->ttyfd, p->report, strlen(p->report));
+	write(p->term->ptyfd, p->report, strlen(p->report));
 }
 
 static void tvterm_set_region(TVterm* p,int ymin, int ymax)
@@ -1282,6 +1282,7 @@ static void tvterm_esc_bracket(TVterm* p, u_char ch)
 			p->wrap = FALSE;
 		case 'd':
 			p->pen.y = varg[0] ? varg[0] - 1: 0;
+			/* XXX: resize(1) specify large x,y */
 			break;
 		case 'm':
 			for (n = 0; n <= narg; n ++) {
@@ -1290,6 +1291,8 @@ static void tvterm_esc_bracket(TVterm* p, u_char ch)
 			break;
 		case 'r':
 			n = varg[1];
+			if (n == 0)
+			    n = p->ycap;
 			if (p->sl != SL_NONE) {
 				if (n == p->ycap) {
 					 n --;
